/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.codelabor.system.access.managers;

import org.codelabor.system.access.daos.AccessLogDAO;
import org.codelabor.system.access.dtos.AccessLogDTO;
import org.codelabor.system.managers.BaseManagerImpl;

/**
 * 접근 로그 매니저 구현 클래스
 * 
 * @author Shin Sangjae
 * 
 */
public class AccessLogManagerImpl extends BaseManagerImpl implements
		AccessLogManager {

	/**
	 * 접근 로그 DAO
	 */
	private AccessLogDAO accessLogDAO;

	/**
	 * 접근 로그 DAO를 설정한다.
	 * 
	 * @param accessLogDAO
	 *            접근 로그 DAO
	 */
	public void setAccessLogAO(AccessLogDAO accessLogDAO) {
		this.accessLogDAO = accessLogDAO;
	}

	/**
	 * 접근 로그 DAO를 설정한다.
	 * 
	 * @param accessLogDAO
	 *            접근 로그 DA0
	 */
	public void setAccessLogDAO(AccessLogDAO accessLogDAO) {
		this.accessLogDAO = accessLogDAO;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.codelabor.system.access.managers.AccessLogManager#accessLog(org.codelabor
	 * .system.access.dtos.AccessLogDTO)
	 */
	public void accessLog(AccessLogDTO accessLogDTO) throws Exception {
		this.accessLogDAO.insert(accessLogDTO);
	}
}
